@@ -207,7 +207,7 @@ class App:
 
     def __init__(self, visible=None, spec=None, add_book=True, impl=None):
         if impl is None:
-            self.impl = xlplatform.App(spec=spec, add_book=add_book)
+            self.impl = xlplatform.App(spec=spec, add_book=add_book, visible=visible)
             if visible or visible is None:
                 self.visible = True
         else:
@@ -431,6 +431,19 @@ class App:
         """
         return Macro(self, name)
 
+    @property
+    def status_bar(self):
+        """
+        Gets or sets the value of the status bar. Returns ``False`` if Excel has control of it.
+
+        .. versionadded:: 0.20.0
+        """
+        return self.impl.status_bar
+
+    @status_bar.setter
+    def status_bar(self, value):
+        self.impl.status_bar = value
+
     def __repr__(self):
         return "<Excel App %s>" % self.pid
 
@@ -716,7 +729,10 @@ class Book:
         """
         if path:
             path = utils.fspath(path)
-        return self.impl.save(path)
+        display_alerts = self.app.display_alerts
+        self.app.display_alerts = False
+        self.impl.save(path)
+        self.app.display_alerts = display_alerts
 
     @property
     def fullname(self):
@@ -1013,11 +1029,15 @@ class Range:
             else:
                 raise ValueError("Invalid arguments")
 
-        self.impl = impl
+        self._impl = impl
 
         # Keyword Arguments
         self._options = options
 
+    @property
+    def impl(self):
+        return self._impl
+
     @property
     def api(self):
         """
@@ -1162,6 +1182,13 @@ class Range:
         """Clears the content and the formatting of a Range."""
         return self.impl.clear()
 
+    @property
+    def has_array(self):
+        """
+        Are we part of an Array formula?
+        """
+        return self.impl.has_array
+
     def end(self, direction):
         """
         Returns a Range object that represents the cell at the end of the region that contains the source range.
@@ -2876,6 +2903,7 @@ def view(obj, sheet=None):
 
     sheet.range('A1').value = obj
     sheet.autofit()
+    sheet.book.app.activate(steal_focus=True)
 
 
 class Macro:
